@@ -25,11 +25,12 @@ from sqlalchemy.orm import backref
 from sqlalchemy.orm.collections import attribute_mapped_collection
 from sqlalchemy.orm import exc
 
-from neutron.db import api as db_api
-from neutron.db import common_db_mixin
 from neutron.db import models_v2
+from neutron_lib.db import api as db_api
 from neutron_lib.db import constants as db_const
 from neutron_lib.db import model_base
+from neutron_lib.db import model_query
+from neutron_lib.db import utils as db_utils
 
 from networking_sfc.db import flowclassifier_db as fc_db
 from networking_sfc.extensions import flowclassifier as ext_fc
@@ -217,7 +218,6 @@ class ServiceGraph(model_base.BASEV2, model_base.HasId, model_base.HasProject):
 
 class SfcDbPlugin(
     ext_sfc.SfcPluginBase,
-    common_db_mixin.CommonDbMixin,
     ext_sg.ServiceGraphPluginBase
 ):
     """Mixin class to add port chain to db_plugin_base_v2."""
@@ -242,10 +242,10 @@ class SfcDbPlugin(
             },
             'chain_id': port_chain['chain_id'],
         }
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _validate_port_pair_groups(self, context, pg_ids, pc_id=None):
-        with db_api.context_manager.reader.using(context):
+        with db_api.CONTEXT_READER.using(context):
             prev_pg_tap_enabled = False
             for pg_id in pg_ids:
                 pg = self._get_port_pair_group(context, pg_id)
@@ -254,7 +254,7 @@ class SfcDbPlugin(
                     raise ext_tap.ConsecutiveTapPPGNotSupported()
                 else:
                     prev_pg_tap_enabled = curr_pg_tap_enabled
-            query = self._model_query(context, PortChain)
+            query = model_query.query_with_hooks(context, PortChain)
             for port_chain_db in query.all():
                 if port_chain_db['id'] == pc_id:
                     continue
@@ -269,7 +269,7 @@ class SfcDbPlugin(
     def _validate_correlation_consistency(self, context, ppg_ids, pc_corr):
         # format like in ServiceFunctionParam.value to aid comparison later:
         pc_corr = jsonutils.dumps(pc_corr)
-        with db_api.context_manager.reader.using(context):
+        with db_api.CONTEXT_READER.using(context):
             for ppg_id in ppg_ids:
                 ppg = self._get_port_pair_group(context, ppg_id)
                 for pp in ppg['port_pairs']:
@@ -279,7 +279,7 @@ class SfcDbPlugin(
                             ppg=ppg_id)
 
     def _validate_flow_classifiers(self, context, fc_ids, pc_id=None):
-        with db_api.context_manager.reader.using(context):
+        with db_api.CONTEXT_READER.using(context):
             fcs = [
                 self._get_flow_classifier(context, fc_id)
                 for fc_id in fc_ids
@@ -289,7 +289,7 @@ class SfcDbPlugin(
                 if fc_assoc and fc_assoc['portchain_id'] != pc_id:
                     raise ext_fc.FlowClassifierInUse(id=fc.id)
 
-            query = self._model_query(context, PortChain)
+            query = model_query.query_with_hooks(context, PortChain)
             for port_chain_db in query.all():
                 if port_chain_db['id'] == pc_id:
                     continue
@@ -315,10 +315,10 @@ class SfcDbPlugin(
     def _setup_chain_group_associations(
         self, context, port_chain, pg_ids
     ):
-        with db_api.context_manager.reader.using(context):
+        with db_api.CONTEXT_READER.using(context):
             chain_group_associations = []
             for pg_id in pg_ids:
-                query = self._model_query(context, ChainGroupAssoc)
+                query = model_query.query_with_hooks(context, ChainGroupAssoc)
                 chain_group_association = query.filter_by(
                     portchain_id=port_chain.id, portpairgroup_id=pg_id
                 ).first()
@@ -332,10 +332,11 @@ class SfcDbPlugin(
     def _setup_chain_classifier_associations(
         self, context, port_chain, fc_ids
     ):
-        with db_api.context_manager.reader.using(context):
+        with db_api.CONTEXT_READER.using(context):
             chain_classifier_associations = []
             for fc_id in fc_ids:
-                query = self._model_query(context, ChainClassifierAssoc)
+                query = model_query.query_with_hooks(
+                    context, ChainClassifierAssoc)
                 chain_classifier_association = query.filter_by(
                     portchain_id=port_chain.id, flowclassifier_id=fc_id
                 ).first()
@@ -354,7 +355,7 @@ class SfcDbPlugin(
         pc = port_chain['port_chain']
         project_id = pc['project_id']
         chain_id = pc['chain_id']
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             chain_parameters = {
                 key: ChainParameter(keyword=key, value=jsonutils.dumps(val))
                 for key, val in pc['chain_parameters'].items()}
@@ -402,18 +403,19 @@ class SfcDbPlugin(
     def get_port_chains(self, context, filters=None, fields=None,
                         sorts=None, limit=None,
                         marker=None, page_reverse=False, default_sg=False):
-        marker_obj = self._get_marker_obj(context, 'port_chain', limit, marker)
-        return self._get_collection(context,
-                                    PortChain,
-                                    self._make_port_chain_dict,
-                                    filters=filters, fields=fields,
-                                    sorts=sorts,
-                                    limit=limit, marker_obj=marker_obj,
-                                    page_reverse=page_reverse)
+        marker_obj = db_utils.get_marker_obj(self, context, 'port_chain',
+                                             limit, marker)
+        return model_query.get_collection(
+            context, PortChain,
+            self._make_port_chain_dict,
+            filters=filters, fields=fields,
+            sorts=sorts,
+            limit=limit, marker_obj=marker_obj,
+            page_reverse=page_reverse)
 
     def get_port_chains_count(self, context, filters=None):
-        return self._get_collection_count(context, PortChain,
-                                          filters=filters)
+        return model_query.get_collection_count(
+            context, PortChain, filters=filters)
 
     @log_helpers.log_method_call
     def get_port_chain(self, context, id, fields=None):
@@ -423,7 +425,7 @@ class SfcDbPlugin(
     @log_helpers.log_method_call
     def _get_port_chain(self, context, id):
         try:
-            return self._get_by_id(context, PortChain, id)
+            return model_query.get_by_id(context, PortChain, id)
         except exc.NoResultFound:
             raise ext_sfc.PortChainNotFound(id=id)
 
@@ -433,7 +435,7 @@ class SfcDbPlugin(
         if self._any_port_chains_in_a_graph(context, {id}):
             raise ext_sg.ServiceGraphPortChainInUse(id=id)
         try:
-            with db_api.context_manager.writer.using(context):
+            with db_api.CONTEXT_WRITER.using(context):
                 pc = self._get_port_chain(context, id)
                 context.session.delete(pc)
         except ext_sfc.PortChainNotFound:
@@ -447,7 +449,7 @@ class SfcDbPlugin(
             if 'flow_classifiers' in pc or 'port_pair_groups' in pc:
                 raise ext_sg.ServiceGraphPortChainInUse(id=id)
 
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             pc_db = self._get_port_chain(context, id)
             for k, v in pc.items():
                 if k == 'flow_classifiers':
@@ -479,7 +481,7 @@ class SfcDbPlugin(
             }
         }
 
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _validate_port_pair_ingress_egress(self, ingress, egress):
         if 'device_id' not in ingress or not ingress['device_id']:
@@ -500,8 +502,8 @@ class SfcDbPlugin(
         """Create a port pair."""
         pp = port_pair['port_pair']
         project_id = pp['project_id']
-        with db_api.context_manager.writer.using(context):
-            query = self._model_query(context, PortPair)
+        with db_api.CONTEXT_WRITER.using(context):
+            query = model_query.query_with_hooks(context, PortPair)
             pp_in_use = query.filter_by(
                 ingress=pp['ingress'], egress=pp['egress']
             ).first()
@@ -537,19 +539,19 @@ class SfcDbPlugin(
     def get_port_pairs(self, context, filters=None, fields=None,
                        sorts=None, limit=None, marker=None,
                        page_reverse=False):
-        marker_obj = self._get_marker_obj(context, 'port_pair',
-                                          limit, marker)
-        return self._get_collection(context,
-                                    PortPair,
-                                    self._make_port_pair_dict,
-                                    filters=filters, fields=fields,
-                                    sorts=sorts,
-                                    limit=limit, marker_obj=marker_obj,
-                                    page_reverse=page_reverse)
+        marker_obj = db_utils.get_marker_obj(self, context, 'port_pair',
+                                             limit, marker)
+        return model_query.get_collection(
+            context, PortPair,
+            self._make_port_pair_dict,
+            filters=filters, fields=fields,
+            sorts=sorts,
+            limit=limit, marker_obj=marker_obj,
+            page_reverse=page_reverse)
 
     def get_port_pairs_count(self, context, filters=None):
-        return self._get_collection_count(context, PortPair,
-                                          filters=filters)
+        return model_query.get_collection_count(
+            context, PortPair, filters=filters)
 
     @log_helpers.log_method_call
     def get_port_pair(self, context, id, fields=None):
@@ -558,20 +560,20 @@ class SfcDbPlugin(
 
     def _get_port_pair(self, context, id):
         try:
-            return self._get_by_id(context, PortPair, id)
+            return model_query.get_by_id(context, PortPair, id)
         except exc.NoResultFound:
             raise ext_sfc.PortPairNotFound(id=id)
 
     def _get_port(self, context, id):
         try:
-            return self._get_by_id(context, models_v2.Port, id)
+            return model_query.get_by_id(context, models_v2.Port, id)
         except exc.NoResultFound:
             raise ext_sfc.PortPairPortNotFound(id=id)
 
     @log_helpers.log_method_call
     def update_port_pair(self, context, id, port_pair):
         new_pp = port_pair['port_pair']
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             old_pp = self._get_port_pair(context, id)
             old_pp.update(new_pp)
             return self._make_port_pair_dict(old_pp)
@@ -579,7 +581,7 @@ class SfcDbPlugin(
     @log_helpers.log_method_call
     def delete_port_pair(self, context, id):
         try:
-            with db_api.context_manager.writer.using(context):
+            with db_api.CONTEXT_WRITER.using(context):
                 pp = self._get_port_pair(context, id)
                 if pp.portpairgroup_id:
                     raise ext_sfc.PortPairInUse(id=id)
@@ -603,7 +605,7 @@ class SfcDbPlugin(
             'group_id': port_pair_group.get('group_id') or 0
         }
 
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _validate_pps_in_ppg(self, portpairs_list, id=None):
         first_check = True
@@ -630,7 +632,7 @@ class SfcDbPlugin(
         pg = port_pair_group['port_pair_group']
         project_id = pg['project_id']
 
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             portpairs_list = [self._get_port_pair(context, pp_id)
                               for pp_id in pg['port_pairs']]
             self._validate_pps_in_ppg(portpairs_list)
@@ -672,19 +674,19 @@ class SfcDbPlugin(
     def get_port_pair_groups(self, context, filters=None, fields=None,
                              sorts=None, limit=None, marker=None,
                              page_reverse=False):
-        marker_obj = self._get_marker_obj(context, 'port_pair_group',
-                                          limit, marker)
-        return self._get_collection(context,
-                                    PortPairGroup,
-                                    self._make_port_pair_group_dict,
-                                    filters=filters, fields=fields,
-                                    sorts=sorts,
-                                    limit=limit, marker_obj=marker_obj,
-                                    page_reverse=page_reverse)
+        marker_obj = db_utils.get_marker_obj(self, context, 'port_pair_group',
+                                             limit, marker)
+        return model_query.get_collection(
+            context, PortPairGroup,
+            self._make_port_pair_group_dict,
+            filters=filters, fields=fields,
+            sorts=sorts,
+            limit=limit, marker_obj=marker_obj,
+            page_reverse=page_reverse)
 
     def get_port_pair_groups_count(self, context, filters=None):
-        return self._get_collection_count(context, PortPairGroup,
-                                          filters=filters)
+        return model_query.get_collection_count(
+            context, PortPairGroup, filters=filters)
 
     @log_helpers.log_method_call
     def get_port_pair_group(self, context, id, fields=None):
@@ -693,13 +695,13 @@ class SfcDbPlugin(
 
     def _get_port_pair_group(self, context, id):
         try:
-            return self._get_by_id(context, PortPairGroup, id)
+            return model_query.get_by_id(context, PortPairGroup, id)
         except exc.NoResultFound:
             raise ext_sfc.PortPairGroupNotFound(id=id)
 
     def _get_flow_classifier(self, context, id):
         try:
-            return self._get_by_id(context, fc_db.FlowClassifier, id)
+            return model_query.get_by_id(context, fc_db.FlowClassifier, id)
         except exc.NoResultFound:
             raise ext_fc.FlowClassifierNotFound(id=id)
 
@@ -707,7 +709,7 @@ class SfcDbPlugin(
     def update_port_pair_group(self, context, id, port_pair_group):
         new_pg = port_pair_group['port_pair_group']
 
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             portpairs_list = [self._get_port_pair(context, pp_id)
                               for pp_id in new_pg.get('port_pairs', [])]
             self._validate_pps_in_ppg(portpairs_list, id)
@@ -729,7 +731,7 @@ class SfcDbPlugin(
     @log_helpers.log_method_call
     def delete_port_pair_group(self, context, id):
         try:
-            with db_api.context_manager.writer.using(context):
+            with db_api.CONTEXT_WRITER.using(context):
                 pg = self._get_port_pair_group(context, id)
                 if pg.chain_group_associations:
                     raise ext_sfc.PortPairGroupInUse(id=id)
@@ -755,7 +757,7 @@ class SfcDbPlugin(
             'port_chains': self._graph_assocs_to_pc_dict(
                 graph_db['graph_chain_associations'])
         }
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _make_graph_chain_assoc_dict(self, assoc_db, fields=None):
         res = {
@@ -763,7 +765,7 @@ class SfcDbPlugin(
             'src_chain': assoc_db['src_chain'],
             'dst_chain': assoc_db['dst_chain']
         }
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _is_there_a_loop(self, parenthood, current_chain, traversed):
         if current_chain not in parenthood:
@@ -781,8 +783,8 @@ class SfcDbPlugin(
                                     port_chains=set(), graph_id=None):
         if not port_chains:
             return False
-        with db_api.context_manager.reader.using(context):
-            query = self._model_query(context, ServiceGraph)
+        with db_api.CONTEXT_READER.using(context):
+            query = model_query.query_with_hooks(context, ServiceGraph)
             for graph_db in query.all():
                 if graph_db['id'] == graph_id:
                     continue
@@ -885,10 +887,10 @@ class SfcDbPlugin(
                     raise ext_sg.ServiceGraphLoopDetected()
 
     def _setup_graph_chain_associations(self, context, graph_db, port_chains):
-        with db_api.context_manager.reader.using(context):
+        with db_api.CONTEXT_READER.using(context):
             graph_chain_associations = []
             for src_chain in port_chains:
-                query = self._model_query(context, GraphChainAssoc)
+                query = model_query.query_with_hooks(context, GraphChainAssoc)
                 for dst_chain in port_chains[src_chain]:
                     graph_chain_association = query.filter_by(
                         service_graph_id=graph_db.id,
@@ -903,17 +905,17 @@ class SfcDbPlugin(
             graph_db.graph_chain_associations = graph_chain_associations
 
     def _get_branches(self, context, filters):
-        return self._get_collection(context,
-                                    GraphChainAssoc,
-                                    self._make_graph_chain_assoc_dict,
-                                    filters=filters)
+        return model_query.get_collection(
+            context, GraphChainAssoc,
+            self._make_graph_chain_assoc_dict,
+            filters=filters)
 
     @log_helpers.log_method_call
     def create_service_graph(self, context, service_graph):
         """Create a Service Graph."""
         service_graph = service_graph['service_graph']
         project_id = service_graph['project_id']
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             port_chains = service_graph['port_chains']
             self._validate_port_chains_for_graph(context, port_chains)
             graph_db = ServiceGraph(id=uuidutils.generate_uuid(),
@@ -930,15 +932,15 @@ class SfcDbPlugin(
                            fields=None, sorts=None, limit=None,
                            marker=None, page_reverse=False):
         """Get Service Graphs."""
-        marker_obj = self._get_marker_obj(context,
-                                          'service_graph', limit, marker)
-        return self._get_collection(context,
-                                    ServiceGraph,
-                                    self._make_service_graph_dict,
-                                    filters=filters, fields=fields,
-                                    sorts=sorts,
-                                    limit=limit, marker_obj=marker_obj,
-                                    page_reverse=page_reverse)
+        marker_obj = db_utils.get_marker_obj(self, context,
+                                             'service_graph', limit, marker)
+        return model_query.get_collection(
+            context, ServiceGraph,
+            self._make_service_graph_dict,
+            filters=filters, fields=fields,
+            sorts=sorts,
+            limit=limit, marker_obj=marker_obj,
+            page_reverse=page_reverse)
 
     @log_helpers.log_method_call
     def get_service_graph(self, context, id, fields=None):
@@ -949,7 +951,7 @@ class SfcDbPlugin(
     @log_helpers.log_method_call
     def _get_service_graph(self, context, id):
         try:
-            return self._get_by_id(context, ServiceGraph, id)
+            return model_query.get_by_id(context, ServiceGraph, id)
         except exc.NoResultFound:
             raise ext_sg.ServiceGraphNotFound(id=id)
 
@@ -957,7 +959,7 @@ class SfcDbPlugin(
     def update_service_graph(self, context, id, service_graph):
         """Update a Service Graph."""
         service_graph = service_graph['service_graph']
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             graph_db = self._get_service_graph(context, id)
             for k, v in service_graph.items():
                 if k == 'port_chains':
@@ -973,7 +975,7 @@ class SfcDbPlugin(
     def delete_service_graph(self, context, id):
         """Delete a Service Graph."""
         try:
-            with db_api.context_manager.writer.using(context):
+            with db_api.CONTEXT_WRITER.using(context):
                 graph = self._get_service_graph(context, id)
                 context.session.delete(graph)
         except ext_sfc.ServiceGraphNotFound:
